require "import"
import "android.content.Context"
import "android.content.Intent"
import "android.content.IntentFilter"
import "android.os.BatteryManager"
import "android.net.ConnectivityManager"
import "android.app.AlarmManager"
import "android.net.wifi.WifiManager"
import "android.os.Environment"
import "android.app.ActivityManager"
import "android.location.LocationManager"
import "android.provider.Settings"
import "android.os.Build"
import "android.bluetooth.BluetoothAdapter"
import "android.telephony.TelephonyManager"

local days = {Sunday="रविवार", Monday="सोमवार", Tuesday="मंगलवार", Wednesday="बुधवार", Thursday="गुरुवार", Friday="शुक्रवार", Saturday="शनिवार"}
local months = {January="जनवरी", February="फरवरी", March="मार्च", April="अप्रैल", May="मई", June="जून", July="जुलाई", August="अगस्त", September="सितंबर", October="अक्टूबर", November="नवंबर", December="दिसंबर"}

function speakDateTime(context)
    local hour = tonumber(os.date("%H"))
    local greeting = (hour >= 5 and hour < 12) and "सुप्रभात!" or (hour >= 12 and hour < 18) and "नमस्कार!" or "शुभ संध्या!"

    -- हिंदी में दिन और महीना
    local day = days[os.date("%A")]
    local month = months[os.date("%B")]
    local currentDate = day .. ", " .. os.date("%d") .. " " .. month .. " " .. os.date("%Y")

    -- समय (12 घंटे फॉर्मेट में)
    local formattedTime = os.date("%I:%M %p"):gsub("AM", "पूर्वाह्न"):gsub("PM", "अपराह्न")

    -- बैटरी स्तर
    local batteryIntent = context.registerReceiver(nil, IntentFilter(Intent.ACTION_BATTERY_CHANGED))
    local level = batteryIntent.getIntExtra(BatteryManager.EXTRA_LEVEL, -1)
    local scale = batteryIntent.getIntExtra(BatteryManager.EXTRA_SCALE, -1)
    local batteryPercent = math.floor((level / scale) * 100)

    -- बैटरी का तापमान
    local temperature = batteryIntent.getIntExtra(BatteryManager.EXTRA_TEMPERATURE, 0) / 10
    local isCharging = batteryIntent.getIntExtra(BatteryManager.EXTRA_STATUS, -1) == BatteryManager.BATTERY_STATUS_CHARGING
    local chargingStatus = isCharging and "फ़ोन अभी चार्ज हो रहा है।" or "फ़ोन अभी चार्ज नहीं हो रहा है।"

    -- नेटवर्क स्टेटस
    local connectivityManager = context.getSystemService(Context.CONNECTIVITY_SERVICE)
    local activeNetwork = connectivityManager.getActiveNetworkInfo()
    local mobileDataStatus = (activeNetwork and activeNetwork.isConnected()) and "मोबाइल डेटा चालू है।" or "मोबाइल डेटा बंद है।"

    -- वाई-फाई नाम
    local wifiManager = context.getSystemService(Context.WIFI_SERVICE)
    local wifiInfo = wifiManager.getConnectionInfo()
    local wifiName = wifiInfo and wifiInfo.getSSID() or "कोई वाई-फाई नहीं जुड़ा।"

    -- ब्लूटूथ स्टेटस
    local bluetoothAdapter = BluetoothAdapter.getDefaultAdapter()
    local bluetoothStatus = (bluetoothAdapter and bluetoothAdapter.isEnabled()) and "ब्लूटूथ चालू है।" or "ब्लूटूथ बंद है।"

    -- डिवाइस जानकारी
    local deviceModel = Build.MODEL
    local deviceBrand = Build.BRAND
    local processor = Build.HARDWARE

    -- फोन का अपटाइम
    local uptime = math.floor((os.clock() / 3600)) .. " घंटे " .. math.floor((os.clock() % 3600) / 60) .. " मिनट"

    -- स्टोरेज स्थिति
    local freeSpace = math.floor(Environment.getExternalStorageDirectory().getFreeSpace() / (1024 * 1024 * 1024))
    local totalSpace = math.floor(Environment.getExternalStorageDirectory().getTotalSpace() / (1024 * 1024 * 1024))

    -- RAM स्थिति
    local activityManager = context.getSystemService(Context.ACTIVITY_SERVICE)
    local memoryInfo = ActivityManager.MemoryInfo()
    activityManager.getMemoryInfo(memoryInfo)
    local availableRAM = math.floor(memoryInfo.availMem / (1024 * 1024))

    -- अगला अलार्म
    local alarmManager = context.getSystemService(Context.ALARM_SERVICE)
    local nextAlarm = alarmManager.getNextAlarmClock()
    local nextAlarmTime = nextAlarm and os.date("%I:%M %p", nextAlarm.getTriggerTime() / 1000) or "कोई अलार्म सेट नहीं है।"

    -- डार्क मोड स्टेटस
    local darkMode = Settings.Secure.getInt(context.getContentResolver(), "ui_night_mode", 0) == 2 and "डार्क मोड चालू है।" or "डार्क मोड बंद है।"

    -- मिस्ड कॉल और SMS की संख्या (डेमो वैल्यू)
    local missedCalls = "3 मिस्ड कॉल"
    local unreadSMS = "5 अपठित संदेश"

    -- मौसम की जानकारी (फिक्स डेटा)
    local temperatureOutside = "30 डिग्री सेल्सियस"
    local weatherCondition = "हल्की धूप और साफ़ मौसम।"

    -- मैसेज तैयार करें
    local message = string.format(
        "%s आज %s है। अभी समय %s हो रहा है। बैटरी स्तर %d%% है। बैटरी का तापमान %0.1f डिग्री सेल्सियस है। %s %s वाई-फाई नेटवर्क %s से जुड़ा है। ब्लूटूथ स्टेटस: %s स्टोरेज में %dGB खाली है, कुल स्टोरेज %dGB है। उपलब्ध RAM %dMB है। अगला अलार्म %s पर सेट है। डिवाइस का ब्रांड %s है और मॉडल %s है। प्रोसेसर: %s। फ़ोन %s से चालू है। %s %s मिस्ड कॉल और %s। आज का मौसम %s तापमान %s",
        greeting, currentDate, formattedTime, batteryPercent, temperature, chargingStatus, mobileDataStatus, wifiName, bluetoothStatus, freeSpace, totalSpace, availableRAM, nextAlarmTime, deviceBrand, deviceModel, processor, uptime, darkMode, missedCalls, unreadSMS, weatherCondition, temperatureOutside
    )

    -- बोलो!
    context.speak(message)
end

speakDateTime(this)
service.playSoundClock()
return true